@@ -15,6 +15,9 @@ class Dispatcher(Resource):
         from twisted.internet import reactor, task
         from twisted.web.server import Site, NOT_DONE_YET
 
+        from txroutes import Dispatcher
+
+
         # Create a Controller
         class Controller(object):
 
@@ -60,8 +63,6 @@ class Dispatcher(Resource):
     def __init__(self):
         Resource.__init__(self)
 
-        self.__path = ['']
-
         self.__controllers = {}
         self.__mapper = routes.Mapper()
 
@@ -70,49 +71,29 @@ class Dispatcher(Resource):
         self.__mapper.connect(name, route, controller=name, **kwargs)
 
     def getChild(self, name, request):
-        self.__path.append(name)
-
         return self
 
-    def render_HEAD(self, request):
-        return self.__render('HEAD', request)
+    def render(self, request):
 
-    def render_GET(self, request):
-        return self.__render('GET', request)
+        wsgi_environ = {}
+        wsgi_environ['REQUEST_METHOD'] = request.method
+        wsgi_environ['PATH_INFO'] = request.path
 
-    def render_POST(self, request):
-        return self.__render('POST', request)
+        result = self.__mapper.match(environ=wsgi_environ)
 
-    def render_PUT(self, request):
-        return self.__render('PUT', request)
+        handler = None
 
-    def render_DELETE(self, request):
-        return self.__render('DELETE', request)
+        if result is not None:
+            controller = result.get('controller', None)
+            controller = self.__controllers.get(controller)
 
-    def __render(self, method, request):
-        try:
-            wsgi_environ = {}
-            wsgi_environ['REQUEST_METHOD'] = method
-            wsgi_environ['PATH_INFO'] = '/'.join(self.__path)
+            if controller is not None:
+                del result['controller']
+                action = result.get('action', None)
 
-            result = self.__mapper.match(environ=wsgi_environ)
-
-            handler = None
-
-            if result is not None:
-                controller = result.get('controller', None)
-                controller = self.__controllers.get(controller)
-
-                if controller is not None:
-                    del result['controller']
-                    action = result.get('action', None)
-
-                    if action is not None:
-                        del result['action']
-                        handler = getattr(controller, action, None)
-
-        finally:
-            self.__path = ['']
+                if action is not None:
+                    del result['action']
+                    handler = getattr(controller, action, None)
 
         if handler:
             return handler(request, **result)
